"use strict";
/// <reference path="../diagram-library/diagramming.d.ts" />
exports.__esModule = true;
var Diagramming = require("diagram-library/diagramming");
var Drawing = require("mindfusion-common/drawing");
var AnchorPoints;
(function (AnchorPoints) {
    AnchorPoints.diagram = null;
    var decision1In3Out;
    var apat2;
    // create a Diagram component that wraps the "diagram" canvas
    var view = Diagramming.DiagramView.create(document.getElementById("diagram"));
    AnchorPoints.diagram = view.diagram;
    // register event handlers
    AnchorPoints.diagram.addEventListener(Diagramming.Events.nodeCreated, onNodeCreated);
    AnchorPoints.diagram.linkHeadShapeSize = 2;
    AnchorPoints.diagram.defaultShape = "Rectangle";
    AnchorPoints.diagram.routeLinks = true;
    AnchorPoints.diagram.roundedLinks = true;
    AnchorPoints.diagram.showGrid = false;
    AnchorPoints.diagram.backBrush = "#e0e9e9";
    var theme = new Diagramming.Theme();
    var shapeNodeStyle = new Diagramming.Style();
    shapeNodeStyle.brush = { type: 'LinearGradientBrush', color1: '#e0e9e9', color2: '#616a7f', angle: 90 };
    shapeNodeStyle.stroke = "#7F7F7F";
    shapeNodeStyle.textColor = "#585A5C";
    shapeNodeStyle.fontName = "Verdana";
    shapeNodeStyle.fontSize = 3;
    shapeNodeStyle.backBrush = "#e0e9e9";
    shapeNodeStyle.nodeEffects = [new Diagramming.GlassEffect()];
    theme.styles["std:ShapeNode"] = shapeNodeStyle;
    AnchorPoints.diagram.style = (shapeNodeStyle);
    var blue = "#2d3956";
    var green = "#5a7444";
    var red = "#ce0000";
    var apat1 = new Diagramming.AnchorPattern([
        new Diagramming.AnchorPoint(50, 0, true, true),
        new Diagramming.AnchorPoint(100, 50, true, true),
        new Diagramming.AnchorPoint(50, 100, true, true),
        new Diagramming.AnchorPoint(0, 50, true, true)
    ]);
    var apat2 = new Diagramming.AnchorPattern([
        new Diagramming.AnchorPoint(10, 0, true, false, Diagramming.MarkStyle.Circle, green),
        new Diagramming.AnchorPoint(50, 0, true, false, Diagramming.MarkStyle.Circle, blue),
        new Diagramming.AnchorPoint(90, 0, true, false, Diagramming.MarkStyle.Circle, red),
        new Diagramming.AnchorPoint(10, 100, false, true, Diagramming.MarkStyle.Rectangle),
        new Diagramming.AnchorPoint(50, 100, false, true, Diagramming.MarkStyle.Rectangle),
        new Diagramming.AnchorPoint(90, 100, false, true, Diagramming.MarkStyle.Rectangle),
        new Diagramming.AnchorPoint(0, 50, true, true, Diagramming.MarkStyle.X)
    ]);
    var pb1 = AnchorPoints.diagram.factory.createShapeNode(new Drawing.Rect(10, 7, 25, 18));
    pb1.setShape(Diagramming.Shape.fromId("Ellipse"));
    pb1.setText("Start");
    pb1.setAnchorPattern(apat1);
    var pb2 = AnchorPoints.diagram.factory.createShapeNode(new Drawing.Rect(20, 78, 25, 18));
    pb2.setText("node 1");
    pb2.setAnchorPattern(apat2);
    var pb3 = AnchorPoints.diagram.factory.createShapeNode(new Drawing.Rect(70, 73, 25, 18));
    pb3.setText("node 2");
    pb3.setAnchorPattern(apat2);
    var pb4 = AnchorPoints.diagram.factory.createShapeNode(new Drawing.Rect(80, 110, 25, 18));
    pb4.setShape(Diagramming.Shape.fromId("Ellipse"));
    pb4.setText("End");
    pb4.setAnchorPattern(apat1);
    decision1In3Out = Diagramming.AnchorPattern.fromId("Decision1In3Out");
    var decb1 = AnchorPoints.diagram.factory.createShapeNode(new Drawing.Rect(20, 35, 30, 20));
    decb1.setShape(Diagramming.Shape.fromId("Decision"));
    decb1.setText("check 1");
    decb1.setAnchorPattern(decision1In3Out);
    var decision2In2Out = Diagramming.AnchorPattern.fromId("Decision2In2Out");
    var decb2 = AnchorPoints.diagram.factory.createShapeNode(new Drawing.Rect(70, 30, 30, 20));
    decb2.setShape(Diagramming.Shape.fromId("Decision"));
    decb2.setText("check 2");
    decb2.setAnchorPattern(decision2In2Out);
    var link = AnchorPoints.diagram.factory.createDiagramLink(decb1, decb2);
    link.route();
    function onNodeCreated(sender, args) {
        var node = args.getNode();
        if (AnchorPoints.diagram.defaultShape.id == "Rectangle")
            node.anchorPattern = apat2;
        else
            node.anchorPattern = decision1In3Out;
    }
    function rBtnSelectNode() {
        AnchorPoints.diagram.defaultShape = (Diagramming.Shape.fromId("Rectangle"));
    }
    AnchorPoints.rBtnSelectNode = rBtnSelectNode;
    function rBtnSelectDecision() {
        AnchorPoints.diagram.defaultShape = (Diagramming.Shape.fromId("Decision"));
    }
    AnchorPoints.rBtnSelectDecision = rBtnSelectDecision;
})(AnchorPoints || (AnchorPoints = {}));
